@@ -31,7 +31,7 @@
  * ------------------------------------------------------------------------ -->
  *
  * @class ConversionOption
- * @sbmlbrief{core} Class of object that encapsulates a conversion option.
+ * @sbmlbrief{core} A single configuration setting for an SBML converter.
  *
  * @htmlinclude libsbml-facility-only-warning.html
  *
@@ -74,23 +74,23 @@
  *      <td><strong>Meaning</strong></td>
  *  </tr>
  * <tr>
- * <td><code>@link ConversionOptionType_t#CNV_TYPE_BOOL CNV_TYPE_BOOL@endlink</code></td>
+ * <td><code>@sbmlconstant{CNV_TYPE_BOOL, ConversionOptionType_t}</code></td>
  * <td>Indicates the value type is a Boolean.</td>
  * </tr>
  * <tr>
- * <td><code>@link ConversionOptionType_t#CNV_TYPE_DOUBLE CNV_TYPE_DOUBLE@endlink</code></td>
+ * <td><code>@sbmlconstant{CNV_TYPE_DOUBLE, ConversionOptionType_t}</code></td>
  * <td>Indicates the value type is a double-sized float.</td>
  * </tr>
  * <tr>
- * <td><code>@link ConversionOptionType_t#CNV_TYPE_INT CNV_TYPE_INT@endlink</code></td>
+ * <td><code>@sbmlconstant{CNV_TYPE_INT, ConversionOptionType_t}</code></td>
  * <td>Indicates the value type is an integer.</td>
  * </tr>
  * <tr>
- * <td><code>@link ConversionOptionType_t#CNV_TYPE_SINGLE CNV_TYPE_SINGLE@endlink</code></td>
+ * <td><code>@sbmlconstant{CNV_TYPE_SINGLE, ConversionOptionType_t}</code></td>
  * <td>Indicates the value type is a float.</td>
  * </tr>
  * <tr>
- * <td><code>@link ConversionOptionType_t#CNV_TYPE_STRING CNV_TYPE_STRING@endlink</code></td>
+  * <td><code>@sbmlconstant{CNV_TYPE_STRING, ConversionOptionType_t}</code></td>
  * <td>Indicates the value type is a string.</td>
  * </tr>
  * </table>
@@ -167,11 +167,11 @@ public:
    * @param type the type of this option
    * @param description the description for this option
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  ConversionOption(std::string key, std::string value="",
+  ConversionOption(const std::string& key, const std::string& value="",
                    ConversionOptionType_t type=CNV_TYPE_STRING,
-                   std::string description="");
+                   const std::string& description="");
 
 
   /**
@@ -181,10 +181,10 @@ public:
    * @param value the value for this option
    * @param description an optional description
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  ConversionOption(std::string key, const char* value,
-                   std::string description="");
+  ConversionOption(const std::string& key, const char* value,
+                   const std::string& description="");
 
 
   /**
@@ -194,10 +194,10 @@ public:
    * @param value the value for this option
    * @param description an optional description
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  ConversionOption(std::string key, bool value,
-                   std::string description="");
+  ConversionOption(const std::string& key, bool value,
+                   const std::string& description="");
 
 
   /**
@@ -207,10 +207,10 @@ public:
    * @param value the value for this option
    * @param description an optional description
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  ConversionOption(std::string key, double value,
-                   std::string description="");
+  ConversionOption(const std::string& key, double value,
+                   const std::string& description="");
 
 
   /**
@@ -220,10 +220,10 @@ public:
    * @param value the value for this option
    * @param description an optional description
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  ConversionOption(std::string key, float value,
-                   std::string description="");
+  ConversionOption(const std::string& key, float value,
+                   const std::string& description="");
 
 
   /**
@@ -233,10 +233,10 @@ public:
    * @param value the value for this option
    * @param description an optional description
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  ConversionOption(std::string key, int value,
-                   std::string description="");
+  ConversionOption(const std::string& key, int value,
+                   const std::string& description="");
 
 
   /**
@@ -244,7 +244,7 @@ public:
    *
    * @param orig the ConversionOption object to copy.
    *
-   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * @throws SBMLConstructorException
    * Thrown if the argument @p orig is @c NULL.
    */
   ConversionOption(const ConversionOption& orig);
@@ -256,7 +256,7 @@ public:
    * @param rhs The object whose values are used as the basis of the
    * assignment.
    *
-   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * @throws SBMLConstructorException
    * Thrown if the argument @p rhs is @c NULL.
    */
   ConversionOption& operator=(const ConversionOption& rhs);
@@ -271,7 +271,7 @@ public:
   /**
    * Creates and returns a deep copy of this ConversionOption object.
    *
-   * @return a (deep) copy of this ConversionOption object.
+   * @return the (deep) copy of this ConversionOption object.
    */
   virtual ConversionOption* clone() const;
 
@@ -281,7 +281,7 @@ public:
    *
    * @return the key, as a string.
    */
-  virtual std::string getKey() const;
+  const std::string& getKey() const;
 
 
   /**
@@ -289,7 +289,7 @@ public:
    *
    * @param key a string representing the key to set.
    */
-  virtual void setKey(std::string key);
+  void setKey(const std::string& key);
 
 
   /**
@@ -297,7 +297,7 @@ public:
    *
    * @return the value of this option, as a string.
    */
-  virtual std::string getValue() const;
+  const std::string& getValue() const;
 
 
   /**
@@ -305,7 +305,7 @@ public:
    *
    * @param value the value to set, as a string.
    */
-  virtual void setValue(std::string value);
+  void setValue(const std::string& value);
 
 
   /**
@@ -313,7 +313,7 @@ public:
    *
    * @return the description of this option.
    */
-  virtual std::string getDescription() const;
+  const std::string& getDescription() const;
 
 
   /**
@@ -321,7 +321,7 @@ public:
    *
    * @param description the description to set for this option.
    */
-  virtual void setDescription(std::string description);
+  void setDescription(const std::string& description);
 
 
   /**
@@ -329,7 +329,7 @@ public:
    *
    * @return the type of this option.
    */
-  virtual ConversionOptionType_t getType() const;
+  ConversionOptionType_t getType() const;
 
 
   /**
@@ -339,7 +339,7 @@ public:
    *
    * @param type the type value to use.
    */
-  virtual void setType(ConversionOptionType_t type);
+  void setType(ConversionOptionType_t type);
 
 
   /**
@@ -354,7 +354,7 @@ public:
    * Set the value of this option to a given Boolean value.
    *
    * Invoking this method will also set the type of the option to
-   * @link ConversionOptionType_t#CNV_TYPE_BOOL CNV_TYPE_BOOL@endlink.
+   * @sbmlconstant{CNV_TYPE_BOOL, ConversionOptionType_t}.
    *
    * @param value the Boolean value to set
    */
@@ -373,7 +373,7 @@ public:
    * Set the value of this option to a given @c double value.
    *
    * Invoking this method will also set the type of the option to
-   * @link ConversionOptionType_t#CNV_TYPE_DOUBLE CNV_TYPE_DOUBLE@endlink.
+   * @sbmlconstant{CNV_TYPE_DOUBLE, ConversionOptionType_t}.
    *
    * @param value the value to set
    */
@@ -392,7 +392,7 @@ public:
    * Set the value of this option to a given @c float value.
    *
    * Invoking this method will also set the type of the option to
-   * @link ConversionOptionType_t#CNV_TYPE_SINGLE CNV_TYPE_SINGLE@endlink.
+   * @sbmlconstant{CNV_TYPE_SINGLE, ConversionOptionType_t}.
    *
    * @param value the value to set
    */
@@ -411,7 +411,7 @@ public:
    * Set the value of this option to a given @c int value.
    *
    * Invoking this method will also set the type of the option to
-   * @link ConversionOptionType_t#CNV_TYPE_INT CNV_TYPE_INT@endlink.
+   * @sbmlconstant{CNV_TYPE_INT, ConversionOptionType_t}.
    *
    * @param value the value to set
    */
