@@ -31,8 +31,7 @@
  * ------------------------------------------------------------------------ -->
  *
  * @class ConversionProperties
- * @sbmlbrief{core} Class of object that encapsulates the properties of an
- * SBML converter.
+ * @sbmlbrief{core} Set of configuration option values for a converter.
  *
  * @htmlinclude libsbml-facility-only-warning.html
  *
@@ -80,7 +79,7 @@ public:
    *
    * @param targetNS the target namespace to convert to
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
   ConversionProperties(SBMLNamespaces* targetNS=NULL);
 
@@ -90,7 +89,7 @@ public:
    *
    * @param orig the object to copy.
    *
-   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * @throws SBMLConstructorException
    * Thrown if the argument @p orig is @c NULL.
    */
   ConversionProperties(const ConversionProperties& orig);
@@ -102,7 +101,7 @@ public:
    * @param rhs The object whose values are used as the basis of the
    * assignment.
    *
-   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * @throws SBMLConstructorException
    * Thrown if the argument @p rhs is @c NULL.
    */
   ConversionProperties& operator=(const ConversionProperties& rhs);
@@ -111,7 +110,7 @@ public:
   /**
    * Creates and returns a deep copy of this ConversionProperties object.
    *
-   * @return a (deep) copy of this ConversionProperties object.
+   * @return the (deep) copy of this ConversionProperties object.
    */
   virtual ConversionProperties* clone() const;
 
@@ -155,7 +154,7 @@ public:
    *
    * @return the description text of the option with the given key.
    */
-  virtual std::string getDescription(std::string key) const;
+  virtual const std::string& getDescription(const std::string& key) const;
 
 
   /**
@@ -165,7 +164,7 @@ public:
    *
    * @return the type of the option with the given key.
    */
-  virtual ConversionOptionType_t  getType(std::string key) const;
+  virtual ConversionOptionType_t  getType(const std::string& key) const;
 
 
   /**
@@ -175,7 +174,7 @@ public:
    *
    * @return the option with the given key.
    */
-  virtual ConversionOption* getOption(std::string key) const;
+  virtual ConversionOption* getOption(const std::string& key) const;
 
   
   /**
@@ -204,11 +203,11 @@ public:
    * for ConversionOption for more information about the types)
    * @param description (optional) the description for the option
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  virtual void addOption(std::string key, std::string value="",
+  virtual void addOption(const std::string& key, const std::string& value="",
                          ConversionOptionType_t type=CNV_TYPE_STRING,
-                         std::string description="");
+                         const std::string& description="");
 
 
   /**
@@ -218,10 +217,10 @@ public:
    * @param value the string value of that option
    * @param description (optional) the description for the option
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  virtual void addOption(std::string key, const char* value,
-                         std::string description="");
+  virtual void addOption(const std::string& key, const char* value,
+                         const std::string& description="");
 
 
   /**
@@ -231,10 +230,10 @@ public:
    * @param value the boolean value of that option
    * @param description (optional) the description for the option
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  virtual void addOption(std::string key, bool value,
-                         std::string description="");
+  virtual void addOption(const std::string& key, bool value,
+                         const std::string& description="");
 
 
   /**
@@ -244,10 +243,10 @@ public:
    * @param value the double value of that option
    * @param description (optional) the description for the option
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  virtual void addOption(std::string key, double value,
-                         std::string description="");
+  virtual void addOption(const std::string& key, double value,
+                         const std::string& description="");
 
 
   /**
@@ -257,10 +256,10 @@ public:
    * @param value the float value of that option
    * @param description (optional) the description for the option
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  virtual void addOption(std::string key, float value,
-                         std::string description="");
+  virtual void addOption(const std::string& key, float value,
+                         const std::string& description="");
 
 
   /**
@@ -270,10 +269,10 @@ public:
    * @param value the integer value of that option
    * @param description (optional) the description for the option
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
-  virtual void addOption(std::string key, int value,
-                         std::string description="");
+  virtual void addOption(const std::string& key, int value,
+                         const std::string& description="");
 
 
   /**
@@ -282,7 +281,7 @@ public:
    * @param key the key for the new option to remove
    * @return the removed option
    */
-  virtual ConversionOption* removeOption(std::string key);
+  virtual ConversionOption* removeOption(const std::string& key);
 
 
   /**
@@ -294,7 +293,7 @@ public:
    * @return @c true if an option with the given @p key exists in
    * this properties object, @c false otherwise.
    */
-  virtual bool hasOption(std::string key) const;
+  virtual bool hasOption(const std::string& key) const;
 
 
   /**
@@ -304,7 +303,7 @@ public:
    *
    * @return the string value of the option with the given key.
    */
-  virtual std::string getValue(std::string key) const;
+  virtual const std::string& getValue(const std::string& key) const;
 
 
   /**
@@ -313,7 +312,7 @@ public:
    * @param key the key for the option
    * @param value the new value
    */
-  virtual void setValue(std::string key, std::string value);
+  virtual void setValue(const std::string& key, const std::string& value);
 
 
   /**
@@ -323,7 +322,7 @@ public:
    *
    * @return the boolean value of the option with the given key.
    */
-  virtual bool getBoolValue(std::string key) const;
+  virtual bool getBoolValue(const std::string& key) const;
 
 
   /**
@@ -333,7 +332,7 @@ public:
    *
    * @param value the new Boolean value.
    */
-  virtual void setBoolValue(std::string key, bool value);
+  virtual void setBoolValue(const std::string& key, bool value);
 
 
   /**
@@ -343,7 +342,7 @@ public:
    *
    * @return the double value of the option with the given key.
    */
-  virtual double getDoubleValue(std::string key) const;
+  virtual double getDoubleValue(const std::string& key) const;
 
 
   /**
@@ -353,7 +352,7 @@ public:
    *
    * @param value the new double value.
    */
-  virtual void setDoubleValue(std::string key, double value);
+  virtual void setDoubleValue(const std::string& key, double value);
 
 
   /**
@@ -363,7 +362,7 @@ public:
    *
    * @return the float value of the option with the given key.
    */
-  virtual float getFloatValue(std::string key) const;
+  virtual float getFloatValue(const std::string& key) const;
 
 
   /**
@@ -373,7 +372,7 @@ public:
    *
    * @param value the new float value.
    */
-  virtual void setFloatValue(std::string key, float value);
+  virtual void setFloatValue(const std::string& key, float value);
 
 
   /**
@@ -383,7 +382,7 @@ public:
    *
    * @return the int value of the option with the given key.
    */
-  virtual int getIntValue(std::string key) const;
+  virtual int getIntValue(const std::string& key) const;
 
 
   /**
@@ -393,7 +392,7 @@ public:
    *
    * @param value the new integer value.
    */
-  virtual void setIntValue(std::string key, int value);
+  virtual void setIntValue(const std::string& key, int value);
 
   /** 
    * Returns the number of options in this Conversion Properties object
