@@ -31,7 +31,7 @@
  * ------------------------------------------------------------------------ -->
  *
  * @class SBMLInitialAssignmentConverter
- * @sbmlbrief{core} SBML converter for replacing initial assignments.
+ * @sbmlbrief{core} Converter that removes SBML <em>initial assignments</em>.
  *
  * @htmlinclude libsbml-facility-only-warning.html
  *
@@ -72,12 +72,12 @@
  * </table>
  * </center>
  *
- * @section usage Configuration and use of SBMLInitialAssignmentConverter
+ * @section SBMLInitialAssignmentConverter-usage Configuration and use of SBMLInitialAssignmentConverter
  *
  * SBMLInitialAssignmentConverter is enabled by creating a
  * ConversionProperties object with the option @c "expandInitialAssignments",
- * and passing this properties object to SBMLDocument::convert().  The
- * converter offers no other options.
+ * and passing this properties object to SBMLDocument::convert(@if java
+ * ConversionProperties@endif).  The converter offers no other options.
  *
  * @copydetails doc_section_using_sbml_converters
  */
@@ -129,7 +129,7 @@ public:
    *
    * @return a (deep) copy of this converter.
    */
-  virtual SBMLConverter* clone() const;
+  virtual SBMLInitialAssignmentConverter* clone() const;
 
 
   /**
@@ -146,7 +146,7 @@ public:
    * object, setting the options desired, and then calling this method on
    * an SBMLInitialAssignmentConverter object to find out if the object's
    * property values match the given ones.  This method is also used by
-   * SBMLConverterRegistry::getConverterFor(@if java const ConversionProperties& props@endif)
+   * SBMLConverterRegistry::getConverterFor(@if java ConversionProperties@endif)
    * to search across all registered converters for one matching particular
    * properties.
    *
@@ -163,16 +163,16 @@ public:
    *
    * This method causes the converter to do the actual conversion work,
    * that is, to convert the SBMLDocument object set by
-   * SBMLConverter::setDocument(@if java const SBMLDocument* doc@endif) and
+   * SBMLConverter::setDocument(@if java SBMLDocument@endif) and
    * with the configuration options set by
-   * SBMLConverter::setProperties(@if java const ConversionProperties *props@endif).
+   * SBMLConverter::setProperties(@if java ConversionProperties@endif).
    *
    * @return  integer value indicating the success/failure of the operation.
    * @if clike The value is drawn from the enumeration
    * #OperationReturnValues_t. @endif@~ The possible values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED@endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
    */
   virtual int convert();
 
