@@ -161,7 +161,7 @@ public:
    * @param programVersion an optional version identification string to write
    * as a comment in the output stream.
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
   XMLOutputStream (  std::ostream&       stream
                    , const std::string&  encoding       = "UTF-8"
@@ -185,7 +185,7 @@ public:
    * @p element name.  (The result has the form
    * <code><em>prefix</em>:<em>name</em></code>.)
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
   void endElement (const std::string& name, const std::string& prefix = "");
 
@@ -215,7 +215,7 @@ public:
    * @p element name.  (The result has the form
    * <code><em>prefix</em>:<em>name</em></code>.)
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
   void startElement (const std::string& name, const std::string& prefix = "");
 
@@ -238,7 +238,7 @@ public:
    * @p element name.  (The result has the form
    * <code><em>prefix</em>:<em>name</em></code>.)
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
   void startEndElement (const std::string& name, const std::string& prefix = "");
 
@@ -633,7 +633,7 @@ protected:
   /**
    * Outputs indentation whitespace.
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
   void writeIndent (bool isEnd = false);
 
@@ -725,7 +725,7 @@ public:
   /**
    * Creates a new XMLOutputStream that wraps stream.
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
   XMLOutputStringStream (  std::ostringstream& stream
                          , const std::string&  encoding     = "UTF-8"
@@ -752,7 +752,7 @@ public:
   /**
    * Creates a new XMLOutputStream that wraps stream.
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
   XMLOutputFileStream (  std::ofstream&      stream
                        , const std::string&  encoding     = "UTF-8"
@@ -784,7 +784,7 @@ BEGIN_C_DECLS
  */
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createAsStdout (char * encoding, int writeXMLDecl);
+XMLOutputStream_createAsStdout (const char * encoding, int writeXMLDecl);
 
 
 /**
@@ -813,10 +813,10 @@ XMLOutputStream_createAsStdout (char * encoding, int writeXMLDecl);
  */
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createAsStdoutWithProgramInfo (char * encoding,
+XMLOutputStream_createAsStdoutWithProgramInfo (const char * encoding,
                                                int writeXMLDecl,
-                                               char * programName,
-                                               char * programVersion);
+                                               const char * programName,
+                                               const char * programVersion);
 
 
 /**
@@ -826,7 +826,7 @@ XMLOutputStream_createAsStdoutWithProgramInfo (char * encoding,
  */
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createAsString (char * encoding, int writeXMLDecl);
+XMLOutputStream_createAsString (const char * encoding, int writeXMLDecl);
 
 
 /**
@@ -837,10 +837,10 @@ XMLOutputStream_createAsString (char * encoding, int writeXMLDecl);
  */
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createAsStringWithProgramInfo (char * encoding,
+XMLOutputStream_createAsStringWithProgramInfo (const char * encoding,
                                                int writeXMLDecl,
-                                               char * programName,
-                                               char * programVersion);
+                                               const char * programName,
+                                               const char * programVersion);
 
 
 /**
@@ -850,7 +850,7 @@ XMLOutputStream_createAsStringWithProgramInfo (char * encoding,
  */
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createFile (char * filename, char * encoding, int writeXMLDecl);
+XMLOutputStream_createFile (const char * filename, const char * encoding, int writeXMLDecl);
 
 
 /**
@@ -861,9 +861,9 @@ XMLOutputStream_createFile (char * filename, char * encoding, int writeXMLDecl);
  */
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createFileWithProgramInfo (char * filename, char * encoding,
-                                           int writeXMLDecl, char * programName,
-                                           char * programVersion);
+XMLOutputStream_createFileWithProgramInfo (const char * filename, const char * encoding,
+                                           int writeXMLDecl, const char * programName,
+                                           const char * programVersion);
 
 
 /**
